IDENTIFICATION DIVISION.
PROGRAM-ID. CHECK.
DATA DIVISION.
WORKING-STORAGE SECTION.
01 MY-DATA.
    05 FILLER.
10 FILLER PIC S9(18) COMP-5 VALUE 1.
10 FILLER PIC S9(18) COMP-5 VALUE 2.
    05 FILLER.
10 FILLER PIC X(1) VALUE "a".
10 FILLER PIC X(1) VALUE "b".
PROCEDURE DIVISION.
    INITIALIZE MY-DATA.
    STOP RUN.
