package main

func main() {
my_data := []any{
    map[string]any{"name": "Alice", "age": 30},
    map[string]any{"name": "Bob", "age": 25},
}
my_data = []any{
    map[string]any{"name": "Alice", "age": 30},
    map[string]any{"name": "Bob", "age": 25},
}
_ = my_data
}
