import java.util.Map;
import java.util.Set;
class Check {
    public static void check() {
var my_data = new boolean[]{
    true,
    false,
    true
};
my_data = new boolean[]{
    true,
    false,
    true
};
    }
}
