using System.Collections.Generic;
var x = new Dictionary<string, object> {
    /* Server configuration */
    ["host"] = "localhost",  /* default host */
    ["port"] = 8080,
    /* Enable debug mode */
    ["debug"] = true
};
