using System.Collections.Generic;
var my_data = new object[] {
    Array.Empty<object>(),
    Array.Empty<object>()
};
my_data = new object[] {
    Array.Empty<object>(),
    Array.Empty<object>()
};
