IDENTIFICATION DIVISION.
PROGRAM-ID. CHECK.
DATA DIVISION.
WORKING-STORAGE SECTION.
01 LITERAL-VALUE.
    05 FILLER PIC X(30) VALUE "hello ""world"" -- not a comment".
PROCEDURE DIVISION.
    STOP RUN.
