object Check {
val x: Any = Map(
    "level1" -> Map("level2" -> Map("level3" -> Map("level4" -> Map("value" -> "deep", "items" -> Array[String]("a", "b"))), "sibling" -> 42), "tags" -> List(Map("name" -> "tag1", "meta" -> Map("priority" -> 1, "labels" -> Array[String]("x", "y"))))),
)
}
