using System.Collections.Generic;
var my_data = new object[] {
    new object[] {new int[] {1, 2}, new string[] {"a", "b"}}
};
my_data = new object[] {
    new object[] {new int[] {1, 2}, new string[] {"a", "b"}}
};
