defmodule Check do
  def x do
    my_data = %{
    "level1" => %{"level2" => %{"level3" => %{"level4" => %{"value" => "deep", "items" => ["a", "b"]}}, "sibling" => 42}, "tags" => [%{"name" => "tag1", "meta" => %{"priority" => 1, "labels" => ["x", "y"]}}]},
}
    _ = my_data
  end
end
