procedure Check is
   X : A_Val := AMap'(
       AEntry ("users", AList'(AMap'(AEntry ("name", AStr ("Bob")), AEntry ("tags", AList'(AStr ("admin"), AStr ("user")))), AMap'(AEntry ("name", AStr ("Carol")), AEntry ("tags", AList'(AStr ("guest"))))))
   );
begin
   null;
end Check;
