my_data <- list(
    # Server configuration
    "host" = "localhost",  # default host
    "port" = 8080,
    # Enable debug mode
    "debug" = TRUE
)
my_data <- list(
    # Server configuration
    "host" = "localhost",  # default host
    "port" = 8080,
    # Enable debug mode
    "debug" = TRUE
)
