fun _declaration() {
    val my_data = mapOf<String, Any?>(
        "name" to "Alice",
        "age" to 30,
        "active" to true,
        "score" to null,
    )
}
fun _assignment() {
    var my_data: Any? = null
    my_data = mapOf<String, Any?>(
        "name" to "Alice",
        "age" to 30,
        "active" to true,
        "score" to null,
    )
}
