require "set"
my_data = Set{
    # before apple
    "apple",
    "banana",  # banana inline
    # trailing
}
my_data = Set{
    # before apple
    "apple",
    "banana",  # banana inline
    # trailing
}
