#lang racket
(define my_data (hash
    ; Server configuration
    "host" "localhost"  ; default host
    "port" 8080
    ; Enable debug mode
    "debug" #t
))
(set! my_data (hash
    ; Server configuration
    "host" "localhost"  ; default host
    "port" 8080
    ; Enable debug mode
    "debug" #t
))
