fun _declaration() {
    val my_data = listOf<Any?>(
        42,
        3.14,
        true,
        false,
        "hello \"world\"",
    )
}
fun _assignment() {
    var my_data: Any? = null
    my_data = listOf<Any?>(
        42,
        3.14,
        true,
        false,
        "hello \"world\"",
    )
}
