object Declaration {
  val my_data = Array[String](
      "C:\\path\\to\\file",
      "back\\\\slash",
      "hello \\\"world\\\"",
  )
}
object Assignment {
  var my_data: Any = null
  my_data = Array[String](
      "C:\\path\\to\\file",
      "back\\\\slash",
      "hello \\\"world\\\"",
  )
}
