object Declaration {
  val my_data = List(
      true,
      "hi",
      Array[Int](1, 2),
      null,
  )
}
object Assignment {
  var my_data: Any = null
  my_data = List(
      true,
      "hi",
      Array[Int](1, 2),
      null,
  )
}
