void (function() {
const my_data = {
    "key\nwith\nnewlines": "value1",
    "key\twith\ttabs": "value2",
    "": "value3",
};
})();
var my_data;
my_data = {
    "key\nwith\nnewlines": "value1",
    "key\twith\ttabs": "value2",
    "": "value3",
};
