my_data = Dict(
    "users" => [Dict("name" => "Bob", "tags" => ["admin", "user"]), Dict("name" => "Carol", "tags" => ["guest"])],
)
my_data = Dict(
    "users" => [Dict("name" => "Bob", "tags" => ["admin", "user"]), Dict("name" => "Carol", "tags" => ["guest"])],
)
