fun _declaration() {
    val my_data = booleanArrayOf(
        true,
        false,
        true,
    )
}
fun _assignment() {
    var my_data: Any? = null
    my_data = booleanArrayOf(
        true,
        false,
        true,
    )
}
