object Declaration {
  val my_data = Array[Array[Double]](
      Array[Double](1.5, 2.5),
      Array[Double](3.5, 4.5),
  )
}
object Assignment {
  var my_data: Any = null
  my_data = Array[Array[Double]](
      Array[Double](1.5, 2.5),
      Array[Double](3.5, 4.5),
  )
}
