fun _declaration() {
    val my_data = mapOf<String, Any?>(
        "level1" to mapOf<String, Any?>("level2" to mapOf<String, Any?>("level3" to mapOf<String, Any?>("level4" to mapOf<String, Any?>("value" to "deep", "items" to arrayOf("a", "b"))), "sibling" to 42), "tags" to listOf<Any?>(mapOf<String, Any?>("name" to "tag1", "meta" to mapOf<String, Any?>("priority" to 1, "labels" to arrayOf("x", "y"))))),
    )
}
fun _assignment() {
    var my_data: Any? = null
    my_data = mapOf<String, Any?>(
        "level1" to mapOf<String, Any?>("level2" to mapOf<String, Any?>("level3" to mapOf<String, Any?>("level4" to mapOf<String, Any?>("value" to "deep", "items" to arrayOf("a", "b"))), "sibling" to 42), "tags" to listOf<Any?>(mapOf<String, Any?>("name" to "tag1", "meta" to mapOf<String, Any?>("priority" to 1, "labels" to arrayOf("x", "y"))))),
    )
}
