import std.json;

void _check() {
auto my_data = JSONValue([
    JSONValue("apple"),
    JSONValue("banana"),
    JSONValue("cherry"),
]);
my_data = JSONValue([
    JSONValue("apple"),
    JSONValue("banana"),
    JSONValue("cherry"),
]);
}
