IDENTIFICATION DIVISION.
PROGRAM-ID. CHECK.
DATA DIVISION.
WORKING-STORAGE SECTION.
01 MY-DATA.
    05 FILLER.
10 F-KEY PIC X(13) VALUE "hello   world".
10 F-VALUE PIC S9(18) COMP-5 VALUE 1.
PROCEDURE DIVISION.
    INITIALIZE MY-DATA.
    STOP RUN.
