void (function() {
const my_data = {
    "name": "Alice",
    "age": 30,
    "active": true,
    "score": null,
};
})();
var my_data;
my_data = {
    "name": "Alice",
    "age": 30,
    "active": true,
    "score": null,
};
export {};
