Imports System.Collections.Generic
Module Check
    Dim x As Object = New Integer()()() {
        New Integer()() {New Integer() {1, 2}, New Integer() {3, 4}},
        New Integer()() {New Integer() {5}}
    }
End Module
