IDENTIFICATION DIVISION.
PROGRAM-ID. CHECK.
DATA DIVISION.
WORKING-STORAGE SECTION.
01 MY-DATA.
    05 FILLER PIC S9(18) COMP-5 VALUE 1.
    05 FILLER PIC X(5) VALUE "hello".
    05 FILLER PIC X(5) VALUE "TRUE".
    05 FILLER PIC X(1) VALUE SPACES.
PROCEDURE DIVISION.
    INITIALIZE MY-DATA.
    STOP RUN.
