using System.Collections.Generic;
var my_data = new Dictionary<string, object> {
    // Server configuration
    ["host"] = "localhost",  // default host
    ["port"] = 8080,
    // Enable debug mode
    ["debug"] = true
};
my_data = new Dictionary<string, object> {
    // Server configuration
    ["host"] = "localhost",  // default host
    ["port"] = 8080,
    // Enable debug mode
    ["debug"] = true
};
