import java.util.Map;
import java.util.Set;
class Check {
    public static void check() {
var my_data = new String[]{
    "price $10",
    "$HOME"
};
my_data = new String[]{
    "price $10",
    "$HOME"
};
    }
}
