fn main() {
    {
        let my_data = vec![
            1.1,
            2.2,
            3.3,
        ];
        let _ = my_data;
    }
    let my_data;
    my_data = vec![
        1.1,
        2.2,
        3.3,
    ];
    let _ = my_data;
}
