IDENTIFICATION DIVISION.
PROGRAM-ID. CHECK.
DATA DIVISION.
WORKING-STORAGE SECTION.
01 MY-DATA.
    05 F-KEY-WITH-NEWLINES PIC X(6) VALUE "value1".
    05 F-KEY-WITH-TABS PIC X(6) VALUE "value2".
    05 F-FILLER PIC X(6) VALUE "value3".
PROCEDURE DIVISION.
    INITIALIZE MY-DATA.
    STOP RUN.
