do {
    let my_data: Any = [
        // Server configuration
        "host": "localhost",  // default host
        "port": 8080,
        // Enable debug mode
        "debug": true,
    ]
}
var my_data: Any
my_data = [
    // Server configuration
    "host": "localhost",  // default host
    "port": 8080,
    // Enable debug mode
    "debug": true,
]
