fun _declaration() {
    val my_data = doubleArrayOf(
        1.1,
        2.2,
        3.3,
    )
}
fun _assignment() {
    var my_data: Any? = null
    my_data = doubleArrayOf(
        1.1,
        2.2,
        3.3,
    )
}
