void (function() {
const my_data = [
    {"name": "Alice", "age": 30},
    {"name": "Bob", "age": 25},
];
})();
var my_data;
my_data = [
    {"name": "Alice", "age": 30},
    {"name": "Bob", "age": 25},
];
export {};
