import java.util.Map;
import java.util.Set;
class Check {
    public static void check() {
var my_data = new Object[]{
    new Object[]{new int[]{1, 2}, new String[]{"a", "b"}}
};
my_data = new Object[]{
    new Object[]{new int[]{1, 2}, new String[]{"a", "b"}}
};
    }
}
