IDENTIFICATION DIVISION.
PROGRAM-ID. CHECK.
DATA DIVISION.
WORKING-STORAGE SECTION.
01 LITERAL-VALUE.
    05 F-LEVEL1.
10 F-LEVEL2.
15 F-LEVEL3.
20 F-LEVEL4.
25 F-VALUE PIC X(4) VALUE "deep".
25 F-ITEMS.
30 FILLER PIC X(1) VALUE "a".
30 FILLER PIC X(1) VALUE "b".
15 F-SIBLING PIC S9(18) COMP-5 VALUE 42.
10 F-TAGS.
15 FILLER.
20 F-NAME PIC X(4) VALUE "tag1".
20 F-META.
25 F-PRIORITY PIC S9(18) COMP-5 VALUE 1.
25 F-LABELS.
30 FILLER PIC X(1) VALUE "x".
30 FILLER PIC X(1) VALUE "y".
PROCEDURE DIVISION.
    STOP RUN.
