import java.util.Map;
import java.util.Set;
class Check {
    public static void check() {
var my_data = new double[]{
    1.1,
    2.2,
    3.3
};
my_data = new double[]{
    1.1,
    2.2,
    3.3
};
    }
}
