import java.util.Map;
import java.util.Set;
class Check {
    public static void check() {
var my_data = Map.ofEntries(
    Map.entry("a", 1),
    Map.entry("b", 2.5),
    Map.entry("c", 3)
);
my_data = Map.ofEntries(
    Map.entry("a", 1),
    Map.entry("b", 2.5),
    Map.entry("c", 3)
);
    }
}
