do {
    let my_data: Any = [
        "users": [["name": "Bob", "tags": ["admin", "user"]], ["name": "Carol", "tags": ["guest"]]],
    ]
}
var my_data: Any
my_data = [
    "users": [["name": "Bob", "tags": ["admin", "user"]], ["name": "Carol", "tags": ["guest"]]],
]
