def my_data = [
    "apple",  // inline comment
    // before banana
    "banana",
    // trailing
] as Set<Object>
my_data = [
    "apple",  // inline comment
    // before banana
    "banana",
    // trailing
] as Set<Object>
