(defparameter *my_data* (list
    "apple"  ; inline comment
    ; before banana
    "banana"
    ; trailing
))
(setf *my_data* (list
    "apple"  ; inline comment
    ; before banana
    "banana"
    ; trailing
))
