local my_data = {
    -- before apple
    ["apple"] = true,
    ["banana"] = true,  -- banana inline
    -- trailing
}
my_data = {
    -- before apple
    ["apple"] = true,
    ["banana"] = true,  -- banana inline
    -- trailing
}
