do {
    let my_data: Any = Set<AnyHashable>([
        "apple",  // inline comment
        // before banana
        "banana",
        // trailing
    ])
}
var my_data: Any
my_data = Set<AnyHashable>([
    "apple",  // inline comment
    // before banana
    "banana",
    // trailing
])
