Dict(
    "level1" => Dict("level2" => Dict("level3" => Dict("level4" => Dict("value" => "deep", "items" => ["a", "b"])), "sibling" => 42), "tags" => [Dict("name" => "tag1", "meta" => Dict("priority" => 1, "labels" => ["x", "y"]))]),
)
