import java.util.Map;
import java.util.Set;
class Check {
    Object x = new java.util.ArrayList<>(java.util.Arrays.asList(
    Map.entry("name", "Alice"),
    Map.entry("age", 30),
    Map.entry("active", true)
));
}
