do {
    let my_data: Any = Set<AnyHashable>([
        // before apple
        "apple",
        "banana",  // banana inline
        // trailing
    ])
}
var my_data: Any
my_data = Set<AnyHashable>([
    // before apple
    "apple",
    "banana",  // banana inline
    // trailing
])
