import java.time.Instant;
import java.util.Map;
import java.util.Set;
class Check {
    public static void check() {
var my_data = Instant.parse("2024-01-15T12:30:00+00:00");
my_data = Instant.parse("2024-01-15T12:30:00+00:00");
    }
}
