IDENTIFICATION DIVISION.
PROGRAM-ID. CHECK.
DATA DIVISION.
WORKING-STORAGE SECTION.
01 MY-DATA.
    *> before apple
    05 FILLER PIC X(5) VALUE "apple".
    05 FILLER PIC X(6) VALUE "banana".  *> banana inline
    *> trailing
PROCEDURE DIVISION.
    STOP RUN.
