using System.Collections.Generic;
var my_data = new object[] {
    42,
    3.14,
    true,
    false,
    "hello \"world\""
};
my_data = new object[] {
    42,
    3.14,
    true,
    false,
    "hello \"world\""
};
