using System.Collections.Generic;
var my_data = new Dictionary<string, double> {
    ["a"] = 1,
    ["b"] = 2.5,
    ["c"] = 3
};
my_data = new Dictionary<string, double> {
    ["a"] = 1,
    ["b"] = 2.5,
    ["c"] = 3
};
