fun _declaration() {
    val my_data = arrayOf(
        arrayOf(intArrayOf(1, 2), intArrayOf(3, 4)),
        arrayOf(intArrayOf(5)),
    )
}
fun _assignment() {
    var my_data: Any? = null
    my_data = arrayOf(
        arrayOf(intArrayOf(1, 2), intArrayOf(3, 4)),
        arrayOf(intArrayOf(5)),
    )
}
