using System.Collections.Generic;
var my_data = new HashSet<object> {
    "apple",  // inline comment
    // before banana
    "banana"
    // trailing
};
my_data = new HashSet<object> {
    "apple",  // inline comment
    // before banana
    "banana"
    // trailing
};
