#import <Foundation/Foundation.h>
void _check(void) {
    id _v = @{
    /* Server configuration */
    @"host": @"localhost",  /* default host */
    @"port": @(8080),
    /* Enable debug mode */
    @"debug": @YES,
};
    (void)_v;
}
