void (function() {
const my_data = [
    42,
    3.14,
    true,
    false,
    "hello \"world\"",
];
})();
var my_data;
my_data = [
    42,
    3.14,
    true,
    false,
    "hello \"world\"",
];
export {};
