IDENTIFICATION DIVISION.
PROGRAM-ID. CHECK.
DATA DIVISION.
WORKING-STORAGE SECTION.
01 LITERAL-VALUE.
    05 FILLER.
10 FILLER PIC X(5) VALUE "TRUE".
10 FILLER PIC X(5) VALUE "FALSE".
    05 FILLER.
10 FILLER PIC X(5) VALUE "TRUE".
10 FILLER PIC X(5) VALUE "TRUE".
PROCEDURE DIVISION.
    STOP RUN.
