from collections import OrderedDict
my_data = OrderedDict([
    ("name", "Alice"),
    ("age", 30),
    ("active", True),
])
my_data = OrderedDict([
    ("name", "Alice"),
    ("age", 30),
    ("active", True),
])
