using System;
using System.Collections.Generic;
var my_data = new Dictionary<string, object> {
    ["date"] = new DateOnly(2024, 1, 15),
    ["datetime"] = new DateTime(2024, 1, 15, 12, 30, 0)
};
my_data = new Dictionary<string, object> {
    ["date"] = new DateOnly(2024, 1, 15),
    ["datetime"] = new DateTime(2024, 1, 15, 12, 30, 0)
};
