void (function() {
const my_data = {
    "users": [{"name": "Bob", "tags": ["admin", "user"]}, {"name": "Carol", "tags": ["guest"]}],
};
})();
var my_data;
my_data = {
    "users": [{"name": "Bob", "tags": ["admin", "user"]}, {"name": "Carol", "tags": ["guest"]}],
};
