using System.Collections.Generic;
var my_data = new int[][][] {
    new int[][] {new int[] {1, 2}, new int[] {3, 4}},
    new int[][] {new int[] {5}}
};
my_data = new int[][][] {
    new int[][] {new int[] {1, 2}, new int[] {3, 4}},
    new int[][] {new int[] {5}}
};
