fun _declaration() {
    val my_data = listOf<Any?>(
        intArrayOf(1, 2),
        arrayOf("a", "b"),
    )
}
fun _assignment() {
    var my_data: Any? = null
    my_data = listOf<Any?>(
        intArrayOf(1, 2),
        arrayOf("a", "b"),
    )
}
