import java.util.Map;
import java.util.Set;
class Check {
    public static void check() {
var my_data = new String[]{
    "C:\\path\\to\\file",
    "back\\\\slash",
    "hello \\\"world\\\""
};
    }
}
