import java.time.LocalDate;
import java.util.Map;
import java.util.Set;
class Check {
    public static void check() {
var my_data = LocalDate.of(2024, 1, 15);
my_data = LocalDate.of(2024, 1, 15);
    }
}
