using System.Collections.Generic;
var my_data = new object[] {
    new object[] {1, "a"},
    new object[] {2, "b"}
};
my_data = new object[] {
    new object[] {1, "a"},
    new object[] {2, "b"}
};
