using System.Collections.Generic;
var my_data = new HashSet<object> {
    // before apple
    "apple",
    "banana"  // banana inline
    // trailing
};
my_data = new HashSet<object> {
    // before apple
    "apple",
    "banana"  // banana inline
    // trailing
};
