import java.util.Map;
import java.util.Set;
class Check {
    public static void check() {
var my_data = new double[][]{
    new double[]{1.5, 2.5},
    new double[]{3.5, 4.5}
};
my_data = new double[][]{
    new double[]{1.5, 2.5},
    new double[]{3.5, 4.5}
};
    }
}
