IDENTIFICATION DIVISION.
PROGRAM-ID. CHECK.
DATA DIVISION.
WORKING-STORAGE SECTION.
01 LITERAL-VALUE.
    05 FILLER PIC X(3) VALUE "foo".
    05 FILLER PIC X(3) VALUE "bar".
    05 FILLER PIC X(3) VALUE "baz".
PROCEDURE DIVISION.
    STOP RUN.
