Imports System.Collections.Generic
Module Check
    Dim x As Object = New Object() {
        New Dictionary(Of String, Object) From {{"name", "Alice"}, {"age", 30}},
        New Dictionary(Of String, Object) From {{"name", "Bob"}, {"age", 25}}
    }
End Module
