#import <Foundation/Foundation.h>
void _check(void) {
id my_data = @[
    @{@"key": @"hello   world", @"value": @(1)},
];
my_data = @[
    @{@"key": @"hello   world", @"value": @(1)},
];
    (void)my_data;
}
