declare -A my_data=(
    ["key\nwith\nnewlines"]="value1"
    ["key\twith\ttabs"]="value2"
    [""]="value3"
)
my_data=(
    ["key\nwith\nnewlines"]="value1"
    ["key\twith\ttabs"]="value2"
    [""]="value3"
)
