(defparameter *my_data* (list
    (cons "users" (list (list (cons "name" "Bob") (cons "tags" (list "admin" "user"))) (list (cons "name" "Carol") (cons "tags" (list "guest")))))
))
(setf *my_data* (list
    (cons "users" (list (list (cons "name" "Bob") (cons "tags" (list "admin" "user"))) (list (cons "name" "Carol") (cons "tags" (list "guest")))))
))
