object Declaration {
  val my_data = Map[String, Double](
      "a" -> 1,
      "b" -> 2.5,
      "c" -> 3,
  )
}
object Assignment {
  var my_data: Any = null
  my_data = Map[String, Double](
      "a" -> 1,
      "b" -> 2.5,
      "c" -> 3,
  )
}
