#include <stdbool.h>
#include <stddef.h>
typedef struct _CVal _CVal;
typedef struct _CKV _CKV;
struct _CVal {
    union {
        _Bool b;
        long long i;
        double f;
        const char *s;
        const _CVal *a;
        const _CKV *m;
    };
};
struct _CKV { const char *k; _CVal v; };
void _check(void) {
    _CVal _v = ((_CVal){.m = (_CKV[]){
    // Server configuration
    {"host", ((_CVal){.s = "localhost"})},  // default host
    {"port", ((_CVal){.i = 8080})},
    // Enable debug mode
    {"debug", ((_CVal){.b = true})},
}});
    (void)_v;
}
