do {
    let my_data: Any = [
        ["name": "Alice", "age": 30],
        ["name": "Bob", "age": 25],
    ]
}
var my_data: Any
my_data = [
    ["name": "Alice", "age": 30],
    ["name": "Bob", "age": 25],
]
