(defparameter *my_data* (list
    (list (cons "name" "Alice") (cons "age" 30))
    (list (cons "name" "Bob") (cons "age" 25))
))
(setf *my_data* (list
    (list (cons "name" "Alice") (cons "age" 30))
    (list (cons "name" "Bob") (cons "age" 25))
))
