object Declaration {
  val my_data = Array[String](
      "price $10",
      "$HOME",
  )
}
object Assignment {
  var my_data: Any = null
  my_data = Array[String](
      "price $10",
      "$HOME",
  )
}
