IDENTIFICATION DIVISION.
PROGRAM-ID. CHECK.
DATA DIVISION.
WORKING-STORAGE SECTION.
01 MY-DATA.
    05 FILLER PIC X(5) VALUE "TRUE".
    05 FILLER PIC X(5) VALUE "FALSE".
    05 FILLER PIC X(5) VALUE "TRUE".
PROCEDURE DIVISION.
    INITIALIZE MY-DATA.
    STOP RUN.
