fn main() {
    {
        let my_data = vec![
            "1",
            "hello",
            "True",
            "None",
        ];
        let _ = my_data;
    }
    let my_data;
    my_data = vec![
        "1",
        "hello",
        "True",
        "None",
    ];
    let _ = my_data;
}
