x <- list(
    "level1" = list("level2" = list("level3" = list("level4" = list("value" = "deep", "items" = list("a", "b"))), "sibling" = 42), "tags" = list(list("name" = "tag1", "meta" = list("priority" = 1, "labels" = list("x", "y")))))
)
