local my_data = {
    ["apple"] = true,  -- inline comment
    -- before banana
    ["banana"] = true,
    -- trailing
}
my_data = {
    ["apple"] = true,  -- inline comment
    -- before banana
    ["banana"] = true,
    -- trailing
}
