fun _declaration() {
    val my_data = setOf<Any?>(
        "apple",
        "banana",
        "cherry",
    )
}
fun _assignment() {
    var my_data: Any? = null
    my_data = setOf<Any?>(
        "apple",
        "banana",
        "cherry",
    )
}
