(defparameter *my_data* (list
    "C:\\path\\to\\file"
    "back\\\\slash"
    "hello \\\"world\\\""
))
(setf *my_data* (list
    "C:\\path\\to\\file"
    "back\\\\slash"
    "hello \\\"world\\\""
))
