def my_data = [
    // before apple
    "apple",
    "banana",  // banana inline
    // trailing
] as Set<Object>
my_data = [
    // before apple
    "apple",
    "banana",  // banana inline
    // trailing
] as Set<Object>
