fun _declaration() {
    val my_data = listOf<Any?>(
        listOf<Any?>(1, "a"),
        listOf<Any?>(2, "b"),
    )
}
fun _assignment() {
    var my_data: Any? = null
    my_data = listOf<Any?>(
        listOf<Any?>(1, "a"),
        listOf<Any?>(2, "b"),
    )
}
