fn main() {
    {
        let my_data = vec![
            vec!["1", "a"],
            vec!["2", "b"],
        ];
        let _ = my_data;
    }
    let my_data;
    my_data = vec![
        vec!["1", "a"],
        vec!["2", "b"],
    ];
    let _ = my_data;
}
