object Declaration {
  val my_data = Array[Array[Array[Int]]](
      Array[Array[Int]](Array[Int](1, 2), Array[Int](3, 4)),
      Array[Array[Int]](Array[Int](5)),
  )
}
object Assignment {
  var my_data: Any = null
  my_data = Array[Array[Array[Int]]](
      Array[Array[Int]](Array[Int](1, 2), Array[Int](3, 4)),
      Array[Array[Int]](Array[Int](5)),
  )
}
