IDENTIFICATION DIVISION.
PROGRAM-ID. CHECK.
DATA DIVISION.
WORKING-STORAGE SECTION.
01 MY-DATA.
    05 FILLER PIC X(15) VALUE "C:\path\to\file".
    05 FILLER PIC X(11) VALUE "back\\slash".
    05 FILLER PIC X(15) VALUE "hello \""world\""".
PROCEDURE DIVISION.
    INITIALIZE MY-DATA.
    STOP RUN.
