import std.json;

void _check() {
auto my_data = JSONValue([
    JSONValue(1),
    JSONValue("hello"),
    JSONValue(true),
    JSONValue(null),
]);
my_data = JSONValue([
    JSONValue(1),
    JSONValue("hello"),
    JSONValue(true),
    JSONValue(null),
]);
}
