val x: Any? = mapOf<String, Any?>(
    "users" to listOf<Any?>(mapOf<String, Any?>("name" to "Bob", "tags" to arrayOf("admin", "user")), mapOf<String, Any?>("name" to "Carol", "tags" to arrayOf("guest"))),
)
