do {
    let my_data: Any = [
        "name": "Alice",
        "age": 30,
        "active": true,
        "score": nil,
    ]
}
var my_data: Any
my_data = [
    "name": "Alice",
    "age": 30,
    "active": true,
    "score": nil,
]
