using System.Collections.Generic;
var my_data = new bool[][] {
    new bool[] {true, false},
    new bool[] {true, true}
};
my_data = new bool[][] {
    new bool[] {true, false},
    new bool[] {true, true}
};
