package main

func main() {
my_data := [][2]any{
    {"name", "Alice"},
    {"age", 30},
    {"active", true},
}
my_data = [][2]any{
    {"name", "Alice"},
    {"age", 30},
    {"active", true},
}
_ = my_data
}
