object Declaration {
  val my_data = Array[Double](
      1.1,
      2.2,
      3.3,
  )
}
object Assignment {
  var my_data: Any = null
  my_data = Array[Double](
      1.1,
      2.2,
      3.3,
  )
}
