fn main() {
    {
        let my_data = vec![
            "48656c6c6f",
        ];
        let _ = my_data;
    }
    let my_data;
    my_data = vec![
        "48656c6c6f",
    ];
    let _ = my_data;
}
