fun _declaration() {
    val my_data = arrayOf(
        doubleArrayOf(1.5, 2.5),
        doubleArrayOf(3.5, 4.5),
    )
}
fun _assignment() {
    var my_data: Any? = null
    my_data = arrayOf(
        doubleArrayOf(1.5, 2.5),
        doubleArrayOf(3.5, 4.5),
    )
}
