my $my_data = {
    # Server configuration
    "host" => "localhost",  # default host
    "port" => 8080,
    # Enable debug mode
    "debug" => 1,
};
$my_data = {
    # Server configuration
    "host" => "localhost",  # default host
    "port" => 8080,
    # Enable debug mode
    "debug" => 1,
};
