(defparameter *my_data* (list
    (cons "name" "Alice")
    (cons "age" 30)
    (cons "active" t)
    (cons "score" nil)
))
(setf *my_data* (list
    (cons "name" "Alice")
    (cons "age" 30)
    (cons "active" t)
    (cons "score" nil)
))
