fun _declaration() {
    val my_data = mapOf<String, Any?>(
        "a" to 1,
        "b" to 2.5,
        "c" to 3,
    )
}
fun _assignment() {
    var my_data: Any? = null
    my_data = mapOf<String, Any?>(
        "a" to 1,
        "b" to 2.5,
        "c" to 3,
    )
}
