using System.Collections.Generic;
var my_data = new string[] {
    "C:\\path\\to\\file",
    "back\\\\slash",
    "hello \\\"world\\\""
};
my_data = new string[] {
    "C:\\path\\to\\file",
    "back\\\\slash",
    "hello \\\"world\\\""
};
