import datetime
my_data = {
    "date": datetime.date(year=2024, month=1, day=15),
    "datetime": datetime.datetime(year=2024, month=1, day=15, hour=12, minute=30, second=0),
}
my_data = {
    "date": datetime.date(year=2024, month=1, day=15),
    "datetime": datetime.datetime(year=2024, month=1, day=15, hour=12, minute=30, second=0),
}
