<?php
$my_data = [
    // before apple
    "apple",
    "banana",  // banana inline
    // trailing
];
$my_data = [
    // before apple
    "apple",
    "banana",  // banana inline
    // trailing
];
