fun _declaration() {
    val my_data = arrayOf(
        booleanArrayOf(true, false),
        booleanArrayOf(true, true),
    )
}
fun _assignment() {
    var my_data: Any? = null
    my_data = arrayOf(
        booleanArrayOf(true, false),
        booleanArrayOf(true, true),
    )
}
