IDENTIFICATION DIVISION.
PROGRAM-ID. CHECK.
DATA DIVISION.
WORKING-STORAGE SECTION.
01 LITERAL-VALUE.
    05 FILLER PIC S9(18) COMP-5 VALUE 42.
    05 FILLER COMP-2 VALUE 3.14.
    05 FILLER PIC X(5) VALUE "TRUE".
    05 FILLER PIC X(5) VALUE "FALSE".
    05 FILLER PIC X(13) VALUE "hello ""world""".
PROCEDURE DIVISION.
    STOP RUN.
