do {
    let my_data: Any = [
        "C:\\path\\to\\file",
        "back\\\\slash",
        "hello \\\"world\\\"",
    ]
}
var my_data: Any
my_data = [
    "C:\\path\\to\\file",
    "back\\\\slash",
    "hello \\\"world\\\"",
]
