do {
    let my_data: Any = [
        "level1": ["level2": ["level3": ["level4": ["value": "deep", "items": ["a", "b"]]], "sibling": 42], "tags": [["name": "tag1", "meta": ["priority": 1, "labels": ["x", "y"]]]]],
    ]
}
var my_data: Any
my_data = [
    "level1": ["level2": ["level3": ["level4": ["value": "deep", "items": ["a", "b"]]], "sibling": 42], "tags": [["name": "tag1", "meta": ["priority": 1, "labels": ["x", "y"]]]]],
]
