IDENTIFICATION DIVISION.
PROGRAM-ID. CHECK.
DATA DIVISION.
WORKING-STORAGE SECTION.
01 LITERAL-VALUE.
    05 F-NAME PIC X(5) VALUE "Alice".
    05 F-AGE PIC S9(18) COMP-5 VALUE 30.
    05 F-ACTIVE PIC X(5) VALUE "TRUE".
PROCEDURE DIVISION.
    STOP RUN.
