def my_data = [
    "users": [["name": "Bob", "tags": ["admin", "user"]], ["name": "Carol", "tags": ["guest"]]],
]
my_data = [
    "users": [["name": "Bob", "tags": ["admin", "user"]], ["name": "Carol", "tags": ["guest"]]],
]
