fun _declaration() {
    val my_data = arrayOf(
        "foo",
        "bar",
        "baz",
    )
}
fun _assignment() {
    var my_data: Any? = null
    my_data = arrayOf(
        "foo",
        "bar",
        "baz",
    )
}
