void (function() {
const my_data = [
    "C:\\path\\to\\file",
    "back\\\\slash",
    "hello \\\"world\\\"",
];
})();
var my_data;
my_data = [
    "C:\\path\\to\\file",
    "back\\\\slash",
    "hello \\\"world\\\"",
];
