import json
var my_data = %*[
    "apple",  # inline comment
    # before banana
    "banana"
    # trailing
]
my_data = %*[
    "apple",  # inline comment
    # before banana
    "banana"
    # trailing
]
