object Declaration {
  val my_data = Array[Array[Boolean]](
      Array[Boolean](true, false),
      Array[Boolean](true, true),
  )
}
object Assignment {
  var my_data: Any = null
  my_data = Array[Array[Boolean]](
      Array[Boolean](true, false),
      Array[Boolean](true, true),
  )
}
