import java.util.Map;
import java.util.Set;
class Check {
    public static void check() {
var my_data = new Object[]{
    Map.ofEntries(Map.entry("name", "Alice"), Map.entry("age", 30)),
    Map.ofEntries(Map.entry("name", "Bob"), Map.entry("age", 25))
};
my_data = new Object[]{
    Map.ofEntries(Map.entry("name", "Alice"), Map.entry("age", 30)),
    Map.ofEntries(Map.entry("name", "Bob"), Map.entry("age", 25))
};
    }
}
