#lang racket
(define my_data (set
    ; before apple
    "apple"
    "banana"  ; banana inline
    ; trailing
))
(set! my_data (set
    ; before apple
    "apple"
    "banana"  ; banana inline
    ; trailing
))
