void (function() {
const my_data = new Set([
    "apple",  // inline comment
    // before banana
    "banana",
    // trailing
]);
})();
var my_data;
my_data = new Set([
    "apple",  // inline comment
    // before banana
    "banana",
    // trailing
]);
export {};
