(defparameter *my_data* (list
    (cons "level1" (list (cons "level2" (list (cons "level3" (list (cons "level4" (list (cons "value" "deep") (cons "items" (list "a" "b")))))) (cons "sibling" 42))) (cons "tags" (list (list (cons "name" "tag1") (cons "meta" (list (cons "priority" 1) (cons "labels" (list "x" "y")))))))))
))
(setf *my_data* (list
    (cons "level1" (list (cons "level2" (list (cons "level3" (list (cons "level4" (list (cons "value" "deep") (cons "items" (list "a" "b")))))) (cons "sibling" 42))) (cons "tags" (list (list (cons "name" "tag1") (cons "meta" (list (cons "priority" 1) (cons "labels" (list "x" "y")))))))))
))
