import java.util.Map;
import java.util.Set;
class Check {
    public static void check() {
var my_data = new Object[]{
    42,
    3.14,
    true,
    false,
    "hello \"world\""
};
my_data = new Object[]{
    42,
    3.14,
    true,
    false,
    "hello \"world\""
};
    }
}
