my_data = struct(
    'level1', struct('level2', struct('level3', struct('level4', struct('value', "deep", 'items', {{"a", "b"}})), 'sibling', 42), 'tags', {{struct('name', "tag1", 'meta', struct('priority', 1, 'labels', {{"x", "y"}}))}})
);
