Imports System.Collections.Generic
Module Check
    ' Server configuration
    ' default host
    ' Enable debug mode
    Dim x As Object = New Dictionary(Of String, Object) From {
        {"host", "localhost"},
        {"port", 8080},
        {"debug", True}
    }
End Module
