using System.Collections.Generic;
var my_data = new Dictionary<string, object> {
    ["users"] = new object[] {new Dictionary<string, object> {["name"] = "Bob", ["tags"] = new string[] {"admin", "user"}}, new Dictionary<string, object> {["name"] = "Carol", ["tags"] = new string[] {"guest"}}}
};
