my_data = Dict(
    "name" => "Alice",
    "age" => 30,
    "active" => true,
    "score" => nothing,
)
my_data = Dict(
    "name" => "Alice",
    "age" => 30,
    "active" => true,
    "score" => nothing,
)
