module Check

type Val =
    | FNull
    | FBool of bool
    | FInt of int64
    | FFloat of float
    | FStr of string
    | FList of Val list
    | FMap of (string * Val) list
    | FSet of Val list

let x: Val = FMap [
    (* Server configuration *)
    ("host", FStr "localhost");  (* default host *)
    ("port", FInt 8080L);
    (* Enable debug mode *)
    ("debug", FBool true)
]
