void (function() {
const my_data = new Set([
    // before apple
    "apple",
    "banana",  // banana inline
    // trailing
]);
})();
var my_data;
my_data = new Set([
    // before apple
    "apple",
    "banana",  // banana inline
    // trailing
]);
export {};
