my_data <- list(
    "users" = list(list("name" = "Bob", "tags" = list("admin", "user")), list("name" = "Carol", "tags" = list("guest")))
)
my_data <- list(
    "users" = list(list("name" = "Bob", "tags" = list("admin", "user")), list("name" = "Carol", "tags" = list("guest")))
)
