IDENTIFICATION DIVISION.
PROGRAM-ID. CHECK.
DATA DIVISION.
WORKING-STORAGE SECTION.
01 LITERAL-VALUE.
    05 FILLER.
10 FILLER COMP-2 VALUE 1.5.
10 FILLER COMP-2 VALUE 2.5.
    05 FILLER.
10 FILLER COMP-2 VALUE 3.5.
10 FILLER COMP-2 VALUE 4.5.
PROCEDURE DIVISION.
    STOP RUN.
