#lang racket
(define my_data (set
    "apple"  ; inline comment
    ; before banana
    "banana"
    ; trailing
))
(set! my_data (set
    "apple"  ; inline comment
    ; before banana
    "banana"
    ; trailing
))
