package main

func main() {
my_data := []string{
    "C:\\path\\to\\file",
    "back\\\\slash",
    "hello \\\"world\\\"",
}
my_data = []string{
    "C:\\path\\to\\file",
    "back\\\\slash",
    "hello \\\"world\\\"",
}
_ = my_data
}
