using System.Collections.Generic;
var my_data = new Dictionary<string, object> {
    ["name"] = "Alice",
    ["score"] = (object?)null,
    ["age"] = 30
};
my_data = new Dictionary<string, object> {
    ["name"] = "Alice",
    ["score"] = (object?)null,
    ["age"] = 30
};
