(defparameter *my_data* (list
    ; before apple
    "apple"
    "banana"  ; banana inline
    ; trailing
))
(setf *my_data* (list
    ; before apple
    "apple"
    "banana"  ; banana inline
    ; trailing
))
