package main

func main() {
my_data := map[string]any{
    "name": "Alice",
    "age": 30,
    "active": true,
    "score": nil,
}
my_data = map[string]any{
    "name": "Alice",
    "age": 30,
    "active": true,
    "score": nil,
}
_ = my_data
}
