#import <Foundation/Foundation.h>
void _check(void) {
id my_data = @{
    @"name": @"Alice",
    @"age": @(30),
    @"active": @YES,
};
my_data = @{
    @"name": @"Alice",
    @"age": @(30),
    @"active": @YES,
};
    (void)my_data;
}
