import java.time.Instant;
import java.time.LocalDate;
import java.util.Map;
import java.util.Set;
class Check {
    public static void check() {
var my_data = Map.ofEntries(
    Map.entry("date", LocalDate.of(2024, 1, 15)),
    Map.entry("datetime", Instant.parse("2024-01-15T12:30:00+00:00"))
);
my_data = Map.ofEntries(
    Map.entry("date", LocalDate.of(2024, 1, 15)),
    Map.entry("datetime", Instant.parse("2024-01-15T12:30:00+00:00"))
);
    }
}
