object Declaration {
  val my_data = Set(
      // before apple
      "apple",
      "banana",  // banana inline
      // trailing
  )
}
object Assignment {
  var my_data: Any = null
  my_data = Set(
      // before apple
      "apple",
      "banana",  // banana inline
      // trailing
  )
}
