Imports System.Collections.Generic
Module Check
    Dim x As Object = New Dictionary(Of String, Object) From {
        {"name", "Alice"},
        {"score", Nothing},
        {"age", 30}
    }
End Module
