import java.util.Map;
import java.util.Set;
class Check {
    public static void check() {
var my_data = Set.of(
    // before apple
    "apple",
    "banana"  // banana inline
    // trailing
);
    }
}
