fun _declaration() {
    val my_data = arrayOf(
        "C:\\path\\to\\file",
        "back\\\\slash",
        "hello \\\"world\\\"",
    )
}
fun _assignment() {
    var my_data: Any? = null
    my_data = arrayOf(
        "C:\\path\\to\\file",
        "back\\\\slash",
        "hello \\\"world\\\"",
    )
}
