my_data = struct(
    ['key', char(10), 'with', char(10), 'newlines'], "value1",
    ['key', char(9), 'with', char(9), 'tabs'], "value2",
    '', "value3"
);
my_data = struct(
    ['key', char(10), 'with', char(10), 'newlines'], "value1",
    ['key', char(9), 'with', char(9), 'tabs'], "value2",
    '', "value3"
);
