using System.Collections.Generic;
var my_data = new object[] {
    new Dictionary<string, object> {["key"] = "hello   world", ["value"] = 1}
};
my_data = new object[] {
    new Dictionary<string, object> {["key"] = "hello   world", ["value"] = 1}
};
