import java.util.Map;
import java.util.Set;
class Check {
    public static void check() {
var my_data = new boolean[][]{
    new boolean[]{true, false},
    new boolean[]{true, true}
};
my_data = new boolean[][]{
    new boolean[]{true, false},
    new boolean[]{true, true}
};
    }
}
