require "set"
my_data = Set{
    "apple",  # inline comment
    # before banana
    "banana",
    # trailing
}
my_data = Set{
    "apple",  # inline comment
    # before banana
    "banana",
    # trailing
}
