IDENTIFICATION DIVISION.
PROGRAM-ID. CHECK.
DATA DIVISION.
WORKING-STORAGE SECTION.
01 MY-DATA.
    05 FILLER.
10 F-NAME PIC X(5) VALUE "Alice".
10 F-AGE PIC S9(18) COMP-5 VALUE 30.
    05 FILLER.
10 F-NAME PIC X(3) VALUE "Bob".
10 F-AGE PIC S9(18) COMP-5 VALUE 25.
PROCEDURE DIVISION.
    STOP RUN.
