package main

func main() {
my_data := []any{
    42,
    3.14,
    true,
    false,
    "hello \"world\"",
}
my_data = []any{
    42,
    3.14,
    true,
    false,
    "hello \"world\"",
}
_ = my_data
}
