fn main() {
    {
        let my_data = vec![
            vec![Vec::<String>::new(), Vec::<String>::new()],
        ];
        let _ = my_data;
    }
    let my_data;
    my_data = vec![
        vec![Vec::<String>::new(), Vec::<String>::new()],
    ];
    let _ = my_data;
}
