#import <Foundation/Foundation.h>
void _check(void) {
id my_data = [NSSet setWithArray:@[
    @"apple",
    @"banana",
    @"cherry",
]];
my_data = [NSSet setWithArray:@[
    @"apple",
    @"banana",
    @"cherry",
]];
    (void)my_data;
}
