package main

func main() {
my_data := map[string]any{
    // Server configuration
    "host": "localhost",  // default host
    "port": 8080,
    // Enable debug mode
    "debug": true,
}
_ = my_data
}
