#import <Foundation/Foundation.h>
void _check(void) {
id my_data = @{
    // Server configuration
    @"host": @"localhost",  // default host
    @"port": @(8080),
    // Enable debug mode
    @"debug": @YES,
};
my_data = @{
    // Server configuration
    @"host": @"localhost",  // default host
    @"port": @(8080),
    // Enable debug mode
    @"debug": @YES,
};
    (void)my_data;
}
