Imports System.Collections.Generic
Module Check
    ' before apple
    ' banana inline
    ' trailing
    Dim x As Object = New HashSet(Of Object) From {
        "apple",
        "banana"
    }
End Module
