(defparameter *my_data* (list
    ; Server configuration
    (cons "host" "localhost")  ; default host
    (cons "port" 8080)
    ; Enable debug mode
    (cons "debug" t)
))
(setf *my_data* (list
    ; Server configuration
    (cons "host" "localhost")  ; default host
    (cons "port" 8080)
    ; Enable debug mode
    (cons "debug" t)
))
