do {
    let my_data: Any = [
        "key\nwith\nnewlines": "value1",
        "key\twith\ttabs": "value2",
        "": "value3",
    ]
}
var my_data: Any
my_data = [
    "key\nwith\nnewlines": "value1",
    "key\twith\ttabs": "value2",
    "": "value3",
]
