#import <Foundation/Foundation.h>
void _check(void) {
id my_data = @{
    @"name": @"Alice",
    @"score": [NSNull null],
    @"age": @(30),
};
my_data = @{
    @"name": @"Alice",
    @"score": [NSNull null],
    @"age": @(30),
};
    (void)my_data;
}
