IDENTIFICATION DIVISION.
PROGRAM-ID. CHECK.
DATA DIVISION.
WORKING-STORAGE SECTION.
01 LITERAL-VALUE.
    05 FILLER PIC X(9) VALUE "price $10".
    05 FILLER PIC X(5) VALUE "$HOME".
PROCEDURE DIVISION.
    STOP RUN.
