using System.Collections.Generic;
var my_data = new object[] {
    true,
    "hi",
    new int[] {1, 2},
    (object?)null
};
my_data = new object[] {
    true,
    "hi",
    new int[] {1, 2},
    (object?)null
};
