IDENTIFICATION DIVISION.
PROGRAM-ID. CHECK.
DATA DIVISION.
WORKING-STORAGE SECTION.
01 LITERAL-VALUE.
    05 FILLER PIC S9(18) COMP-5 VALUE 1.
    05 FILLER PIC S9(18) COMP-5 VALUE 2.
    05 FILLER PIC S9(18) COMP-5 VALUE 3.
PROCEDURE DIVISION.
    STOP RUN.
