IDENTIFICATION DIVISION.
PROGRAM-ID. CHECK.
DATA DIVISION.
WORKING-STORAGE SECTION.
01 LITERAL-VALUE.
    05 F-DATE PIC X(10) VALUE "2024-01-15".
    05 F-DATETIME PIC X(25) VALUE "2024-01-15T12:30:00+00:00".
PROCEDURE DIVISION.
    STOP RUN.
