fun _declaration() {
    val my_data = listOf<Any?>(
        1,
        2.5,
        3,
    )
}
fun _assignment() {
    var my_data: Any? = null
    my_data = listOf<Any?>(
        1,
        2.5,
        3,
    )
}
