$my_data = @{
    # Server configuration
    "host" = "localhost";  # default host
    "port" = 8080;
    # Enable debug mode
    "debug" = $true
}
$my_data = @{
    # Server configuration
    "host" = "localhost";  # default host
    "port" = 8080;
    # Enable debug mode
    "debug" = $true
}
