import java.util.Map;
import java.util.Set;
class Check {
    public static void check() {
var my_data = Map.ofEntries(
    Map.entry("name", "Alice"),
    Map.entry("age", 30),
    Map.entry("active", true)
);
my_data = Map.ofEntries(
    Map.entry("name", "Alice"),
    Map.entry("age", 30),
    Map.entry("active", true)
);
    }
}
