my_data = Set.new([
    # before apple
    "apple",
    "banana",  # banana inline
    # trailing
])
my_data = Set.new([
    # before apple
    "apple",
    "banana",  # banana inline
    # trailing
])
