do {
    let my_data: Any = [
        42,
        3.14,
        true,
        false,
        "hello \"world\"",
    ]
}
var my_data: Any
my_data = [
    42,
    3.14,
    true,
    false,
    "hello \"world\"",
]
