object Declaration {
  val my_data = Array[Boolean](
      true,
      false,
      true,
  )
}
object Assignment {
  var my_data: Any = null
  my_data = Array[Boolean](
      true,
      false,
      true,
  )
}
