my_data = Set.new([
    "apple",  # inline comment
    # before banana
    "banana",
    # trailing
])
my_data = Set.new([
    "apple",  # inline comment
    # before banana
    "banana",
    # trailing
])
